@@ -98,7 +98,7 @@ class CollectionVersionRetrieveMixin:
         """
         Returns a CollectionVersions queryset for specified distribution.
         """
-        if not self.request and not self.args and not self.kwargs:
+        if getattr(self, "swagger_fake_view", False):
             # drf_spectacular get filter from get_queryset().model
             # and it fails when "path" is not on self.kwargs
             return CollectionVersion.objects.none()
@@ -179,7 +179,7 @@ class CollectionViewSet(
         """
         Returns a Collections queryset for specified distribution.
         """
-        if not self.request and not self.args and not self.kwargs:
+        if getattr(self, "swagger_fake_view", False):
             # drf_spectacular get filter from get_queryset().model
             # and it fails when "path" is not on self.kwargs
             return Collection.objects.none()
@@ -367,12 +367,12 @@ class CollectionUploadViewSet(
         async_result = self._dispatch_import_collection_task(
             temp_file.pk, distro.repository, **kwargs
         )
-        CollectionImport.objects.create(task_id=async_result.id)
+        CollectionImport.objects.create(task_id=async_result.pk)
 
         data = {
             "task": reverse(
                 "collection-imports-detail",
-                kwargs={"path": path, "pk": async_result.id},
+                kwargs={"path": path, "pk": async_result.pk},
                 request=None,
             )
         }
