@@ -58,8 +58,7 @@ class InstallCollectionTestCase(unittest.TestCase):
         self.addCleanup(self.distributions_api.delete, distribution.pulp_href)
 
         with tempfile.TemporaryDirectory() as temp_dir:
-            # FIXME Use --no-deps while https://pulp.plan.io/issues/7751 is not addressed
-            cmd = "ansible-galaxy collection install {} -c -s {} -p {} --no-deps".format(
+            cmd = "ansible-galaxy collection install {} -c -s {} -p {}".format(
                 collection_name, distribution.client_url, temp_dir
             )
 
